@@ -5,10 +5,9 @@ This contribution adds support for LiveJournal OpenID service in the form
 username.livejournal.com. Username is retrieved from the identity url.
 """
 import urlparse
-import logging
-logger = logging.getLogger(__name__)
 
 from social_auth.backends import OpenIDBackend, OpenIdAuth, USERNAME
+from social_auth.backends.exceptions import AuthMissingParameter
 
 
 # LiveJournal conf
@@ -40,7 +39,7 @@ class LiveJournalAuth(OpenIdAuth):
     def openid_url(self):
         """Returns LiveJournal authentication URL"""
         if not self.data.get(LIVEJOURNAL_USER_FIELD):
-            raise ValueError('Missing LiveJournal user identifier')
+            raise AuthMissingParameter(self, LIVEJOURNAL_USER_FIELD)
         return LIVEJOURNAL_URL % self.data[LIVEJOURNAL_USER_FIELD]
 
 
